@@ -63,8 +63,9 @@ MiniMapView::mousePressEvent(QMouseEvent *event)
     float sectorSize, woffset, hoffset;
     CalculateOffsets(sectorSize, woffset, hoffset);
 
-    m_selection = Coordinate((event->x() - woffset) / sectorSize,
-                             (event->y() - hoffset) / sectorSize);
+    const QPoint mousePos = event->position().toPoint();
+    m_selection = Coordinate((mousePos.x() - woffset) / sectorSize,
+                             (mousePos.y() - hoffset) / sectorSize);
 
     const Sector *sector = m_map->sector(m_selection);
     if (sector && !sector->hasPlanet())
